@@ -30,18 +30,18 @@ __license__   = "LGPL"
 import os
 import pprint
 
-import debug
-import orca
-import settings
+import orca # Deal with this during final Python 3 conversion
+from . import debug
+from . import settings
 
 _settingsManager = getattr(orca, '_settingsManager')
 
 # The same fields than in orca_gui_prefs.py:
 #
 (HANDLER, DESCRIP, MOD_MASK1, MOD_USED1, KEY1, CLICK_COUNT1, OLDTEXT1, \
- TEXT1, MODIF, EDITABLE) = range(10)
+ TEXT1, MODIF, EDITABLE) = list(range(10))
 
-(ACTUAL, REPLACEMENT) = range(2)
+(ACTUAL, REPLACEMENT) = list(range(2))
 
 class OrcaPrefs:
 
@@ -137,7 +137,7 @@ class OrcaPrefs:
         while thisIter != None:
             iterChild = treeModel.iter_children(thisIter)
             while iterChild != None:
-                values = treeModel.get(iterChild, 0,1,2,3,4,5,6,7,8,9)
+                values = treeModel.get(iterChild, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9)
                 if values[MODIF]:
                     self._writeKeyBinding(prefs, values)
                 iterChild = treeModel.iter_next(iterChild)
@@ -313,7 +313,7 @@ class OrcaPrefs:
             # settings manager.
             voiceDict = voices[voice]
             newDict = {}
-            for key, value in voiceDict.items():
+            for key, value in list(voiceDict.items()):
                 newDict[str(key)] = value
             voicesStr += "'%s' : orca.acss.ACSS(" % voice
             voicesStr += pprint.pformat(newDict) + "),\n"
