@@ -28,14 +28,14 @@ __license__   = "LGPL"
 import pyatspi
 from gi.repository import Atspi, Atk
 
-import braille
-import generator
-import orca
-import orca_state
-import settings
+import orca # Deal with this during final Python 3 conversion
+from . import braille
+from . import generator
+from . import orca_state
+from . import settings
 
-from braille_rolenames import shortRoleNames
-from orca_i18n import ngettext  # for ngettext support
+from .braille_rolenames import shortRoleNames
+from .orca_i18n import ngettext
 
 _settingsManager = getattr(orca, '_settingsManager')
 
@@ -92,17 +92,21 @@ class BrailleGenerator(generator.Generator):
         except:
             focusedRegion = None
         for region in result:
+            try:
+                role = obj.getRole()
+            except:
+                role = None
             if isinstance(region, (braille.Component, braille.Text)) \
                and region.accessible == obj:
                 focusedRegion = region
                 break
             elif isinstance(region, braille.Text) \
-                 and obj.getRole() == pyatspi.ROLE_COMBO_BOX \
+                 and role == pyatspi.ROLE_COMBO_BOX \
                  and region.accessible.parent == obj:
                 focusedRegion = region
                 break
             elif isinstance(region, braille.Component) \
-                 and obj.getRole() == pyatspi.ROLE_TABLE_CELL \
+                 and role == pyatspi.ROLE_TABLE_CELL \
                  and region.accessible.parent == obj:
                 focusedRegion = region
                 break
@@ -152,7 +156,10 @@ class BrailleGenerator(generator.Generator):
             try:
                 return obj.getLocalizedRoleName()
             except:
-                pass
+                return ''
+
+        if not role:
+            return ''
 
         nonlocalized = Atspi.role_get_name(role)
         atkRole = Atk.role_for_name(nonlocalized)
@@ -189,8 +196,11 @@ class BrailleGenerator(generator.Generator):
         I wonder if this string should be moved to settings.py.]]]
         """
         result = []
-        alertAndDialogCount = \
-            self._script.utilities.unfocusedAlertAndDialogCount(obj)
+        try:
+            alertAndDialogCount = \
+                self._script.utilities.unfocusedAlertAndDialogCount(obj)
+        except:
+            alertAndDialogCount = 0
         if alertAndDialogCount > 0:
             # Translators: this tells the user how many unfocused
             # alert and dialog windows plus the total number of
@@ -237,8 +247,11 @@ class BrailleGenerator(generator.Generator):
             # page tab lists might be a nice thing to include. Logged
             # as bugzilla bug 319751.]]]
             #
-            role = parent.getRole()
-            if role != pyatspi.ROLE_FILLER \
+            try:
+                role = parent.getRole()
+            except:
+                role = None
+            if role and role != pyatspi.ROLE_FILLER \
                 and role != pyatspi.ROLE_SECTION \
                 and role != pyatspi.ROLE_SPLIT_PANE \
                 and role != pyatspi.ROLE_DESKTOP_FRAME \
@@ -253,8 +266,7 @@ class BrailleGenerator(generator.Generator):
             # container for the grouped objects.  When we detect this,
             # we add the label to the overall context.]]]
             #
-            if parent.getRole() in [pyatspi.ROLE_FILLER,
-                                    pyatspi.ROLE_PANEL]:
+            if role in [pyatspi.ROLE_FILLER, pyatspi.ROLE_PANEL]:
                 label = self._script.utilities.displayedLabel(parent)
                 if label and len(label) and not label.isspace():
                     if not excludeRadioButtonGroup:
@@ -282,7 +294,10 @@ class BrailleGenerator(generator.Generator):
         details.
         """
         result = []
-        relations = obj.getRelationSet()
+        try:
+            relations = obj.getRelationSet()
+        except:
+            relations = []
         for relation in relations:
             if relation.getRelationType() ==  pyatspi.RELATION_LABELLED_BY:
                 labelledBy = relation.getTarget(0)
@@ -334,9 +349,12 @@ class BrailleGenerator(generator.Generator):
             text = None
         if text and (self._script.utilities.isTextArea(obj) \
                      or (obj.getRole() in [pyatspi.ROLE_LABEL])):
-            [lineString, startOffset, endOffset] = text.getTextAtOffset(
-                text.caretOffset,
-                pyatspi.TEXT_BOUNDARY_LINE_START)
+            try:
+                [lineString, startOffset, endOffset] = text.getTextAtOffset(
+                    text.caretOffset, pyatspi.TEXT_BOUNDARY_LINE_START)
+            except:
+                return include
+
             include = startOffset == 0
             if include:
                 for relation in obj.getRelationSet():
@@ -380,6 +398,11 @@ class BrailleGenerator(generator.Generator):
             while content and isinstance(content[-1], Space):
                 content = content[0:-1]
             for element in content:
+                try:
+                    element = element.decode("UTF-8")
+                except UnicodeEncodeError:
+                    pass
+
                 if isinstance(element, Space) and prior:
                     combined += element.delimiter
                     prior = None
