@@ -31,11 +31,11 @@ import pyatspi
 import time
 import unicodedata
 
-import debug
-import keynames
-import orca_state
-import settings
-from orca_i18n import C_
+from . import debug
+from . import keynames
+from . import orca_state
+from . import settings
+from .orca_i18n import C_
 
 KEYBOARD_EVENT     = "keyboard"
 BRAILLE_EVENT      = "braille"
@@ -86,7 +86,8 @@ class InputEvent:
             orca_state.clickCount = 1
             return
 
-        if self.time - lastInputEvent.time < settings.doubleClickTimeout:
+        if self.time - lastInputEvent.time < settings.doubleClickTimeout \
+            and lastInputEvent.event_string == self.event_string:
             # Cap the possible number of clicks at 3.
             if orca_state.clickCount < 3:
                 orca_state.clickCount += 1
@@ -230,7 +231,7 @@ class KeyboardEvent(InputEvent):
 
         return self.event_string in \
             ["F1", "F2", "F3", "F4", "F5", "F6",
-             "F7","F8", "F9", "F10", "F11", "F12"]
+             "F7", "F8", "F9", "F10", "F11", "F12"]
 
     def isLockingKey(self):
         """Return True if this is a locking key."""
@@ -268,7 +269,7 @@ class KeyboardEvent(InputEvent):
 
         orcaMods = settings.orcaModifierKeys
         try:
-            orcaMods = map(lambda x: x.encode('UTF-8'), orcaMods)
+            orcaMods = [x.encode('UTF-8') for x in orcaMods]
         except (UnicodeDecodeError, UnicodeEncodeError):
             pass
 
@@ -281,6 +282,9 @@ class KeyboardEvent(InputEvent):
     def isOrcaModified(self):
         """Return True if this key is Orca modified."""
 
+        if orca_state.bypassNextCommand:
+            return False
+
         return self.modifiers & settings.ORCA_MODIFIER_MASK
 
     def isPrintableKey(self):
@@ -314,7 +318,7 @@ class KeyboardEvent(InputEvent):
         if not self.isPrintableKey():
             return False
 
-        if settings.learnModeEnabled:
+        if orca_state.learnModeEnabled:
             return False
 
         script = orca_state.activeScript
@@ -378,6 +382,8 @@ class KeyboardEvent(InputEvent):
             return False
         if not orca_state.lastInputEvent:
             return False
+        if isinstance(self, MouseButtonEvent):
+            return False
         if self.hw_code == orca_state.lastInputEvent.hw_code \
            and self.type == orca_state.lastInputEvent.type:
             return True
@@ -389,11 +395,9 @@ class KeyboardEvent(InputEvent):
         if we presented the event. False if there was some reason the event
         was not worthy of presentation."""
 
-        if self.shouldEcho == False:
-            return False
-
-        if self.isOrcaModified():
-            return False
+        if not orca_state.learnModeEnabled:
+            if self.shouldEcho == False or self.isOrcaModified():
+                return False
 
         try:
             role = orca_state.locusOfFocus.getRole()
@@ -403,20 +407,26 @@ class KeyboardEvent(InputEvent):
         if role == pyatspi.ROLE_PASSWORD_TEXT:
             return False
 
-        # Normally we present key presses; this is problematic when the user is
-        # being prompted for a password in a terminal. See bgo 668025.
-        if self.isPressedKey() == (role == pyatspi.ROLE_TERMINAL):
-            return False
-
+        # Worst. Hack. EVER. We have no reliable way of knowing a password is
+        # being entered into a terminal -- other than the fact that the text
+        # typed ain't there. As a result, we have to do special things when
+        # not in special modes. :( See bgo 668025.
         if role == pyatspi.ROLE_TERMINAL:
-            try:
-                text = orca_state.locusOfFocus.queryText()
-                string = text.getText(0, -1).strip()
-            except:
-                pass
-            else:
-                if not string.endswith(self.event_string):
-                    return False
+            if not self.isPressedKey():
+                try:
+                    text = orca_state.locusOfFocus.queryText()
+                    o = text.caretOffset
+                    string = text.getText(o-1, o)
+                except:
+                    pass
+                else:
+                    if not self.event_string in [string, 'space']:
+                        return False
+            elif not (orca_state.learnModeEnabled or self.isLockingKey()):
+                return False
+
+        elif not self.isPressedKey():
+            return False
 
         orca_state.lastKeyEchoTime = time.time()
         debug.println(debug.LEVEL_FINEST,
@@ -479,11 +489,11 @@ class InputEventHandler:
         return (self.function == other.function)
 
     def processInputEvent(self, script, inputEvent):
-        """Processes an input event.  If settings.learnModeEnabled is True,
-        this will merely report the description of the input event to braille
-        and speech.  If settings.learnModeEnabled is False, this will call the
-        function bound to this InputEventHandler instance, passing the
-        inputEvent as the sole argument to the function.
+        """Processes an input event.  If learnModeEnabled is True,
+        this will merely present the description of the input event via
+        If learnModeEnabled is False, this will call the function bound
+        to this InputEventHandler instance, passing the inputEvent as
+        the sole argument to the function.
 
         This function is expected to return True if it consumes the
         event; otherwise it is expected to return False.
@@ -496,7 +506,7 @@ class InputEventHandler:
 
         consumed = False
 
-        if settings.learnModeEnabled and self._learnModeEnabled:
+        if orca_state.learnModeEnabled and self._learnModeEnabled:
             if self.description:
                 script.presentMessage(self.description)
                 consumed = True
