@@ -29,15 +29,13 @@ __copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc." \
                 "Copyright (c) 2012 Igalia, S.L."
 __license__   = "LGPL"
 
-import argparse
+import gc
 import os
-import subprocess
+import pyatspi
 import re
 import signal
+import subprocess
 import sys
-import time
-
-from types import MethodType
 
 try:
     from gi.repository.Gio import Settings
@@ -45,14 +43,6 @@ try:
 except:
     a11yAppSettings = None
 
-# We're going to force the name of the app to "orca" so we
-# will end up showing us as "orca" to the AT-SPI.  If we don't
-# do this, the name can end up being "-c".  See bug 364452 at
-# http://bugzilla.gnome.org/show_bug.cgi?id=364452 for more
-# information.
-#
-sys.argv[0] = "orca"
-import pyatspi
 try:
     # This can fail due to gtk not being available.  We want to
     # be able to recover from that if possible.  The main driver
@@ -67,14 +57,31 @@ try:
 except:
     pass
 
-# Importing anything that requires a functioning settings manager
-# instance should NOT be done here.
-#
-import debug
-import orca_platform
-import settings
-from orca_i18n import _
-from orca_i18n import ngettext
+from .settings_manager import SettingsManager
+_settingsManager = SettingsManager()
+
+from .event_manager import EventManager
+_eventManager = EventManager()
+
+from .script_manager import ScriptManager
+_scriptManager = ScriptManager()
+
+from . import braille
+from . import debug
+from . import notification_messages
+from . import orca_state
+from . import settings
+from . import speech
+from .input_event import BrailleEvent
+from .input_event import KeyboardEvent
+from .orca_i18n import _
+from .orca_i18n import ngettext
+
+try:
+    # If we don't have an active desktop, we will get a RuntimeError.
+    from . import mouse_review
+except RuntimeError:
+    pass
 
 def onEnabledChanged(gsetting, key):
     try:
@@ -85,345 +92,9 @@ def onEnabledChanged(gsetting, key):
     if key == 'screen-reader-enabled' and not enabled:
         shutdown()
 
-class Options(argparse.Namespace):
-    """Class to handle getting run-time options."""
+def getSettingsManager():
+    return _settingsManager
 
-    canEnable = {'speech':'enableSpeech',
-                 'braille':'enableBraille',
-                 'braille-monitor':'enableBrailleMonitor',
-                 'main-window':'showMainWindow',
-                 'splash-window':'showSplashWindow'}
-
-    enable = None
-    disable = None
-    profiles = None
-    userPrefsDir = None
-
-    def __init__(self, **kwargs):
-        """Initialize the Options class."""
-
-        super(Options, self).__init__(**kwargs)
-
-        self.desktopRunning = False
-        try:
-            if Gdk.Display.get_default():
-                self.desktopRunning = True
-        except:
-            pass
-
-        self.settings = {}
-        self.cannotEnable = []
-        self._validFeaturesPrinted = False
-        self.setupRequested = False
-        self.showGUI = False
-        self.debug = False
-        self.debugFile = None
-
-    def validate(self):
-        """Validate the commandline options."""
-
-        if self.userPrefsDir != None:
-            try:
-                os.chdir(self.userPrefsDir)
-            except:
-                debug.printException(debug.LEVEL_FINEST)
-                self.userPrefsDir = None
-
-        if self.profiles == None:
-            self.profiles = []
-
-        if self.guiSetupRequested or self.textSetupRequested:
-            self.setupRequested = True
-            self.showGUI = self.desktopRunning and not self.textSetupRequested
-
-        if self.showHelp:
-            self._printMessageAndExit(parser.print_help)
-
-        if self.listApps and self.desktopRunning:
-            apps = filter(lambda x: x != None, pyatspi.Registry.getDesktop(0))
-            names = [app.name for app in apps]
-            message = "\n".join(names)
-            if message:
-                self._printMessageAndExit(message)
-
-        enable = []
-
-        if self.enable != None:
-            for i in self.enable.split(","):
-                if not i in self.canEnable:
-                    self.cannotEnable.append(i)
-                else:
-                    enable.append(i)
-
-        self.enable = enable
-
-        disable = []
-
-        if self.disable != None:
-            for i in self.disable.split(","):
-                if not i in self.canEnable:
-                    self.cannotEnable.append(i)
-                else:
-                    disable.append(i)
-
-        self.disable = disable
-
-        if self.debugFile:
-            self.debug = True
-        elif self.debug:
-            self.debugFile = time.strftime('debug-%Y-%m-%d-%H:%M:%S.out')
-
-    def _printMessageAndExit(self, msg):
-        """Prints the specified message string and then exits."""
-
-        # The use of os._exit() to immediately kill a child process
-        # after a fork() is documented at docs.python.org.
-        #
-        # pylint: disable-msg=W0212
-        #
-        pid = os.fork()
-        if pid:
-            os.waitpid(pid, 0)
-            os._exit(0)
-        else:
-            if type(msg) == MethodType:
-                msg()
-            else:
-                print msg
-            os._exit(0)
-
-    def convertToSettings(self):
-        """Converts known items (currently just those which can be enabled
-        or disabled), stores them in the self.settings dictionary and then
-        returns that dictionary."""
-
-        toEnable = map(self.canEnable.get, self.enable)
-        for item in toEnable:
-            self.settings[item] = True
-
-        toDisable = map(self.canEnable.get, self.disable)
-        for item in toDisable:
-            self.settings[item] = False
-
-        self.presentCannotEnable()
-
-        return self.settings
-
-    def presentCannotEnable(self):
-        """Presents any non-enable-able items which the user asked us to
-        enable/disable. Returns True if there were invalid items; otherwise
-        returns False."""
-
-        if self.cannotEnable:
-            # Translators: This message is displayed when the user
-            # tries to enable or disable a feature via an argument,
-            # but specified an invalid feature. Valid features are:
-            # speech, braille, braille-monitor, main-window, and
-            # splash-window. These items are not localized and are
-            # presented in a list after this message.
-            #
-            msg = _("The following items can be enabled or disabled:") \
-                  + ", ".join(self.canEnable)
-
-            if not self._validFeaturesPrinted:
-                print(msg)
-                self._validFeaturesPrinted = True
-            return True
-
-        return False
-
-def presentInvalidOptions(invalidOptions):
-    """Presents any invalid options to the user. Returns True if there were
-    invalid options to present and a message printed; otherwise returns False.
-    """
-
-    if invalidOptions:
-        # Translators: This message is displayed when the user tries to start
-        # Orca and includes an invalid option as an argument. After the message,
-        # the list of arguments, as typed by the user, is displayed.
-        #
-        msg = _("The following arguments are not valid: ")
-        print(msg + " ".join(invalidOptions))
-        return True
-
-    return False
-
-parser = argparse.ArgumentParser(
-    description = _("orca - scriptable screen reader and magnifier"),
-    # Translators: this is text being sent to a terminal and we want to keep
-    # the text lines within terminal boundaries.
-    #
-    epilog = _("If Orca has not been previously set up by the user, Orca\n"
-               "will automatically launch the preferences set up unless\n"
-               "the -n or --no-setup option is used.\n\n"
-               "Report bugs to orca-list@gnome.org."),
-    add_help = False, formatter_class = argparse.RawTextHelpFormatter)
-
-parser.add_argument(
-    "-?", "--help", action = "store_true", dest = "showHelp",
-    # Translators: this is the description of the command line option
-    # '-?, --help' that is used to display usage information.
-    #
-    help = _("Show this help message"))
-
-parser.add_argument(
-    "-v", "--version", action = "version", version = orca_platform.version,
-    help = orca_platform.version)
-
-parser.add_argument(
-    "-l", "--list-apps", action = "store_true", dest = "listApps",
-    # Translators: this is a testing option for the command line.  It prints
-    # the names of applications known to the accessibility infrastructure
-    # to stdout and then exits.
-    #
-    help = _("Print the known running applications"))
-
-parser.add_argument(
-    "--debug", action = "store_true", dest = "debug",
-    # Translators: this enables debug output for Orca.  The
-    # YYYY-MM-DD-HH:MM:SS portion is a shorthand way of saying that the file
-    # name will be formed from the current date and time with 'debug' in front
-    # and '.out' at the end.  The 'debug' and '.out' portions of this string
-    # should not be translated (i.e., it will always start with 'debug' and end
-    # with '.out', regardless of the locale.).
-    #
-    help = _("Send debug output to debug-YYYY-MM-DD-HH:MM:SS.out"))
-
-parser.add_argument(
-    "--debug-file", action = "store", dest = "debugFile",
-    default = time.strftime("debug-%Y-%m-%d-%H:%M:%S.out"),
-    # Translators: this enables debug output for Orca and overrides the name
-    # of the debug file Orca will use for debug output if the --debug option
-    # is used.
-    #
-    help = _("Send debug output to the specified file"))
-
-parser.add_argument(
-    "-s", "--setup", "--gui-setup", action = "store_true",
-    dest = "guiSetupRequested",
-    # Translators: this is the description of the command line option
-    # '-s, --setup, --gui-setup' that will initially display a GUI dialog that
-    # would allow the user to set their Orca preferences.
-    #
-    help = _("Set up user preferences"))
-
-parser.add_argument(
-    "-t", "--text-setup", action = "store_true",
-    dest = "textSetupRequested",
-    # Translators: this is the description of the command line option
-    # '-t, --text-setup' that will initially display a list of questions in
-    # text form, that the user will need to answer, before Orca will startup.
-    # For this to happen properly, Orca will need to be run from a terminal
-    # window.
-    #
-    help = _("Set up user preferences (text version)"))
-
-parser.add_argument(
-    "-n", "--no-setup", action = "store_true", dest = "bypassSetup",
-    # Translators: this is the description of the command line option
-    # '-n, --no-setup' that means that Orca will startup without setting up any
-    # user preferences.
-    #
-    help = _("Skip set up of user preferences"))
-
-parser.add_argument(
-    "-u", "--user-prefs-dir", action = "store", dest = "userPrefsDir",
-    # Translators: this is the description of the command line option
-    # '-u, --user-prefs-dir=dirname' that allows you to specify an alternate
-    # location for the user preferences.
-    #
-    help = _("Use alternate directory for user preferences"))
-
-parser.add_argument(
-    "-e", "--enable", action = "store", dest = "enable",
-    metavar = "|".join(Options.canEnable),
-    # Translators: if the user supplies an option via the '-e, --enable'
-    # command line option, it will be automatically enabled as Orca is started.
-    #
-    help = _("Force use of option"))
-
-parser.add_argument(
-    "-d", "--disable", action = "store", dest = "disable",
-    metavar = "|".join(Options.canEnable),
-    # Translators: if the user supplies an option via the '-d, --disable'
-    # command line option, it will be automatically disabled as Orca is started.
-    #
-    help = _("Prevent use of option"))
-
-parser.add_argument(
-    "-i", "--import-file", action = "append", dest = "profiles",
-    # Translators: this is the Orca command line option to import to Orca a user
-    # profile from a given file
-    #
-    help = _("Import a profile from a given orca profile file"))
-
-parser.add_argument(
-    "-q", "--quit", action = "store_true", dest = "quit",
-    # Translators: this is the Orca command line option that will quit Orca.
-    # The user would run the Orca shell script again from a terminal window.
-    # If this command line option is specified, the script will quit any
-    # instances of Orca that are already running.
-    #
-    help = _("Quits Orca (if shell script used)"))
-
-parser.add_argument(
-    "-f", "--forcequit", action = "store_true", dest = "forceQuit",
-    # Translators: this is the Orca command line option that will force the
-    # termination of Orca.
-    # The user would run the Orca shell script again from a terminal window.
-    # If this command line option is specified, the script will quit any
-    # instances of Orca that are already running.
-    #
-    help = _("Forces orca to be terminated immediately."))
-
-parser.add_argument(
-    "--replace", action = "store_true", dest = "replace",
-    # Translators: this is the Orca command line option to tell Orca to replace
-    # any existing Orca process(es) that might be running.
-    #
-    help = _("Replace a currently running Orca"))
-
-options, invalidOpts = parser.parse_known_args(sys.argv[1].split(),
-                                               namespace = Options())
-options.validate()
-
-# This needs to occur prior to our importing anything which might in turn
-# import anything which might expect to be able to use the Settings Manager
-# You have been warned.
-#
-from settings_manager import SettingsManager
-_settingsManager = SettingsManager(prefsDir=options.userPrefsDir)
-if _settingsManager is None:
-    print "Could not load the settings manager. Exiting."
-    sys.exit(1)
-
-from event_manager import EventManager
-_eventManager = EventManager()
-
-from script_manager import ScriptManager
-_scriptManager = ScriptManager()
-
-try:
-    # If we don't have an active desktop, we will get a RuntimeError.
-    import mouse_review
-except RuntimeError:
-    pass
-
-if settings.useDBus:
-    import dbus.mainloop.glib
-    dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
-    import dbusserver
-
-import braille
-import httpserver
-import orca_state
-import speech
-import notification_messages
-
-from input_event import BrailleEvent
-from input_event import KeyboardEvent
-
-import gc
 if settings.debugMemoryUsage:
     gc.set_debug(gc.DEBUG_UNCOLLECTABLE
                  | gc.DEBUG_COLLECTABLE
@@ -438,10 +109,6 @@ EXIT_CODE_HANG = 50
 #
 _userSettings = None
 
-# Command line options that override any other settings.
-#
-_commandLineSettings = {}
-
 # A subset of the original Xmodmap info prior to our stomping on it.
 # Right now, this is just for the user's chosen Orca modifier(s).
 #
@@ -586,7 +253,7 @@ def _processKeyboardEvent(event):
         script.exitLearnMode(keyboardEvent)
     if orca_state.capturingKeys:
         return False
-    if settings.listShortcutsModeEnabled:
+    if orca_state.listShortcutsModeEnabled:
         return listShortcuts(keyboardEvent)
     if notification_messages.listNotificationMessagesModeEnabled:
         return notification_messages.listNotificationMessages(keyboardEvent)
@@ -608,7 +275,7 @@ def _processKeyboardEvent(event):
     elif not keyboardEvent.isModifierKey():
         orca_state.bypassNextCommand = False
  
-    return isOrcaModifier or settings.learnModeEnabled
+    return isOrcaModifier or orca_state.learnModeEnabled
 
 ########################################################################
 #                                                                      #
@@ -639,7 +306,7 @@ def _processBrailleEvent(event):
     except:
         debug.printException(debug.LEVEL_SEVERE)
 
-    if (not consumed) and settings.learnModeEnabled:
+    if (not consumed) and orca_state.learnModeEnabled:
         consumed = True
 
     return consumed
@@ -740,14 +407,6 @@ def loadUserSettings(script=None, inputEvent=None, skipReloadMessage=False):
 
     # Shutdown the output drivers and give them a chance to die.
 
-    # Only exit the D-Bus server if we're in an environment where there 
-    # is a D-Bus session bus already running.  This helps prevent nastiness
-    # on the login screen.
-    #
-    if settings.useDBus:
-        dbusserver.shutdown()
-
-    httpserver.shutdown()
     speech.shutdown()
     braille.shutdown()
 
@@ -767,22 +426,12 @@ def loadUserSettings(script=None, inputEvent=None, skipReloadMessage=False):
         _profile = _settingsManager.profile
         try:
             _userSettings = _settingsManager.getGeneralSettings(_profile)
-            if options.debug:
-                debug.debugLevel = debug.LEVEL_ALL
-                debug.eventDebugLevel = debug.LEVEL_OFF
-                debug.debugFile = open(options.debugFile, 'w', 0)
         except ImportError:
             debug.printException(debug.LEVEL_FINEST)
         except:
             debug.printException(debug.LEVEL_SEVERE)
 
-    # If any settings were added to the command line, they take
-    # precedence over everything else.
-    #
-    for key in _commandLineSettings:
-        setattr(settings, key, _commandLineSettings[key])
-
-    if settings.enableSpeech:
+    if _settingsManager.getSetting('enableSpeech'):
         try:
             speech.init()
             if reloaded and not skipReloadMessage:
@@ -802,7 +451,7 @@ def loadUserSettings(script=None, inputEvent=None, skipReloadMessage=False):
         debug.println(debug.LEVEL_CONFIGURATION,
                       "Speech module has NOT been initialized.")
 
-    if settings.enableBraille:
+    if _settingsManager.getSetting('enableBraille'):
         try:
             braille.init(_processBrailleEvent, settings.tty)
         except:
@@ -833,14 +482,6 @@ def loadUserSettings(script=None, inputEvent=None, skipReloadMessage=False):
     _scriptManager.activate()
     _eventManager.activate()
 
-    # Only start the D-Bus server if we're in an environment where there 
-    # is a D-Bus session bus already running.  This helps prevent nastiness
-    # on the login screen.
-    #
-    if settings.useDBus:
-        dbusserver.init()
-    httpserver.init()
-
     debug.println(debug.LEVEL_FINEST, 'INFO: User Settings Loaded')
 
     return True
@@ -902,24 +543,6 @@ def showMainWindowGUI(script=None, inputEvent=None):
 
     return True
 
-def _showPreferencesConsole(script=None, inputEvent=None):
-    """Displays the user interace to configure Orca and set up
-    user preferences via a command line interface.
-
-    Returns True to indicate the input event has been consumed.
-    """
-
-    try:
-        module = __import__(settings.consolePreferencesModule,
-                            globals(),
-                            locals(),
-                            [''])
-        module.showPreferencesUI(_commandLineSettings)
-    except:
-        debug.printException(debug.LEVEL_SEVERE)
-
-    return True
-
 def helpForOrca(script=None, inputEvent=None, page=""):
     """Show Orca Help window (part of the GNOME Access Guide).
 
@@ -1108,7 +731,7 @@ def quitOrca(script=None, inputEvent=None):
     Returns True to indicate the input event has been consumed.
     """
 
-    if settings.quitOrcaNoConfirmation:
+    if _settingsManager.getSetting("quitOrcaNoConfirmation"):
         shutdown()
     else:
         try:
@@ -1148,7 +771,7 @@ def showSplashGUI(script=None, inputEvent=None):
                             globals(),
                             locals(),
                             [''])
-        if _commandLineSettings.get("showSplashWindow", True):
+        if _settingsManager.getSetting("showSplashWindow"):
             module.showSplashUI()
         else:
             module.hideSplashUI()
@@ -1158,34 +781,10 @@ def showSplashGUI(script=None, inputEvent=None):
 
     return True
 
-
 # If True, this module has been initialized.
 #
 _initialized = False
 
-def setProcessName():
-    """Attempts to set the process name to 'orca'."""
-
-    # Disabling the import error of setproctitle.
-    # pylint: disable-msg=F0401
-    try:
-        from setproctitle import setproctitle
-    except ImportError:
-        pass
-    else:
-        setproctitle('orca')
-        return True
-
-    try:
-        from ctypes import cdll
-        libc = cdll.LoadLibrary('libc.so.6')
-        libc.prctl(15, 'orca', 0, 0, 0)
-        return True
-    except:
-        pass
-
-    return False
-
 def init(registry):
     """Initialize the orca module, which initializes the speech and braille
     modules.  Also builds up the application list, registers for AT-SPI events,
@@ -1234,8 +833,6 @@ def start(registry):
     if not _initialized:
         init(registry)
 
-    setProcessName()
-
     # Do not hang on startup if we can help it.
     #
     if settings.timeoutCallback and (settings.timeoutTime > 0):
@@ -1395,19 +992,6 @@ def examineProcesses():
         debug.println(
             debug.LEVEL_ALL, '%3i. %s (pid: %s) %s' % (i+1, name, pid, cmd))
 
-def multipleOrcas():
-    """Returns True if multiple instances of Orca are running
-    which are owned by the same user."""
-
-    openFile = os.popen('pgrep -u %s orca' % os.getuid())
-    pids = openFile.read()
-    openFile.close()
-    orcas = [int(p) for p in pids.split()]
-
-    pid = os.getpid()
-    ppid = os.getppid()
-    return len(filter(lambda p: p not in [pid, ppid], orcas)) > 0
-
 def cleanupGarbage():
     """Cleans up garbage on the heap."""
     gc.collect()
@@ -1438,52 +1022,9 @@ def main():
     signal.signal(signal.SIGQUIT, shutdownOnSignal)
     signal.signal(signal.SIGSEGV, abortOnSignal)
 
-    if presentInvalidOptions(invalidOpts) and multipleOrcas():
-        die(0)
-
-    _commandLineSettings.update(options.convertToSettings())
-    for profile in options.profiles:
-        # Translators: This message is what is presented to the user
-        # when he/she attempts to import a settings profile, but the
-        # import failed for some reason.
-        #
-        msg = _("Unable to import profile.")
-        try:
-            if _settingsManager.importProfile(profile):
-                # Translators: This message is what is presented to the user
-                # when he/she successfully imports a settings profile.
-                #
-                msg = _("Profile import success.")
-        except KeyError as ex:
-            # Translators: This message is what is presented to the user
-            # when he/she attempts to import a settings profile but the
-            # import failed due to a bad key.
-            #
-            msg = _("Import failed due to an unrecognized key: %s") % ex
-        except IOError as ex:
-            msg = "%s: %s" % (ex.strerror, ex.filename)
-        except:
-            continue
-
-        print msg
-        if multipleOrcas():
-            die(0)
-
     if not _settingsManager.isAccessibilityEnabled():
         _settingsManager.setAccessibility(True)
 
-    if options.setupRequested and not (options.bypassSetup or options.showGUI):
-        _showPreferencesConsole()
-
-    if not options.desktopRunning:
-        print "Cannot start Orca because it cannot connect"
-        print "to the Desktop.  Please make sure the DISPLAY"
-        print "environment variable has been set."
-        return 1
-
-    sys.path.insert(0, _settingsManager.getPrefsDir())
-    sys.path.insert(0, '') # current directory
-
     init(pyatspi.Registry)
 
     try:
@@ -1501,25 +1042,6 @@ def main():
         if window and not orca_state.locusOfFocus:
             setLocusOfFocus(None, window)
 
-    # Check to see if the user wants the configuration GUI. It's
-    # done here so that the user's existing preferences can be used
-    # to set the initial GUI state.  We'll also force the set to
-    # be run if the preferences file doesn't exist, unless the
-    # user has bypassed any setup via the --no-setup switch.
-    #
-    if options.setupRequested and not options.bypassSetup and options.showGUI:
-        showPreferencesGUI()
-    elif not options.bypassSetup \
-         and (not _userSettings or _settingsManager.isFirstStart()):
-        if options.desktopRunning:
-            showPreferencesGUI()
-        else:
-            _showPreferencesConsole()
-        _settingsManager.setFirstStart()
-    elif options.bypassSetup:
-        loadUserSettings(skipReloadMessage=True)
-        _settingsManager.setFirstStart()
-
     try:
         start(pyatspi.Registry) # waits until we stop the registry
     except:
