@@ -41,20 +41,20 @@ __license__   = "LGPL"
 
 import pyatspi
 
-import braille_generator
-import debug
-import flat_review
-import formatting
-import label_inference
-import keybindings
-import orca_state
-import script_utilities
-import settings
-import speech_generator
-import structural_navigation
-import where_am_I
-import bookmarks
-import tutorialgenerator
+from . import braille_generator
+from . import debug
+from . import flat_review
+from . import formatting
+from . import label_inference
+from . import keybindings
+from . import orca_state
+from . import script_utilities
+from . import settings
+from . import speech_generator
+from . import structural_navigation
+from . import where_am_I
+from . import bookmarks
+from . import tutorialgenerator
 
 class Script:
     """The specific focus tracking scripts for applications.
@@ -73,8 +73,8 @@ class Script:
         if app:
             try:
                 self.name = self.app.name
-            except LookupError:
-                msg = 'script.__init__: LookupError trying to get app.name'
+            except (LookupError, RuntimeError):
+                msg = 'script.__init__: Error trying to get app.name'
                 debug.println(debug.LEVEL_FINE, msg)
                 self.name = "default"
         else:
@@ -192,7 +192,7 @@ class Script:
         braille.py) that match the given inputEventHandler passed.
         """
         return [command
-                for command, handler in self.brailleBindings.iteritems()
+                for command, handler in list(self.brailleBindings.items())
                 if inputEventHandler == handler]
 
     def getFormatting(self):
@@ -317,7 +317,7 @@ class Script:
         whether or not the script is active.
         """
 
-        import orca
+        import orca # Deal with this during final Python 3 conversion
         _scriptManager = getattr(orca, '_scriptManager')
         _settingsManager = getattr(orca, '_settingsManager')
 
@@ -365,8 +365,8 @@ class Script:
 
         try:
             role = event.source.getRole()
-        except LookupError:
-            msg = 'script.processObjectEvent: LookupError getting role'
+        except (LookupError, RuntimeError):
+            msg = 'script.processObjectEvent: Error getting role'
             debug.println(debug.LEVEL_FINE, msg)
             return
 
@@ -399,7 +399,7 @@ class Script:
         # to the order in which they were added.  So...we need to do something
         # different here.  Logged as bugzilla bug 319781.]]]
         #
-        for key in self.listeners.keys():
+        for key in list(self.listeners.keys()):
             if event.type.startswith(key):
                 self.listeners[key](event)
 
@@ -428,6 +428,7 @@ class Script:
             skip = True
             reason = "more recent event of the same type in the same object"
         elif event.type in focus and event.source != cachedEvent.source \
+             and event.type == cachedEvent.type \
              and event.detail1 == cachedEvent.detail1:
             skip = True
             reason = "more recent event of the same type in a different object"
