@@ -24,11 +24,12 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2011. Orca Team."
 __license__   = "LGPL"
 
-import debug
-import orca
-import orca_state
+import orca # Deal with this during final Python 3 conversion
 
-from scripts import apps, toolkits
+from . import debug
+from . import orca_state
+
+from .scripts import apps, toolkits
 
 _settingsManager = getattr(orca, '_settingsManager')
 _eventManager = getattr(orca, '_eventManager')
@@ -36,6 +37,7 @@ _eventManager = getattr(orca, '_eventManager')
 class ScriptManager:
 
     def __init__(self):
+        debug.println(debug.LEVEL_FINEST, 'INFO: Initializing script manager')
         self.appScripts = {}
         self.toolkitScripts = {}
         self._appModules = apps.__all__
@@ -60,6 +62,7 @@ class ScriptManager:
              'Earlybird':        'Thunderbird',
              'bug-buddy':        'gnome_segv2',
              'gaim':             'pidgin',
+             'empathy-chat':     'empathy',
              'gnome-calculator': 'gcalctool',
              'Nereid':           'Banshee',
              'vte':              'gnome-terminal'}
@@ -68,20 +71,25 @@ class ScriptManager:
              'clutter':          'CALLY'}
 
         self.setActiveScript(None, "__init__")
+        debug.println(debug.LEVEL_FINEST, 'INFO: Script manager initialized')
 
     def activate(self):
         """Called when this script manager is activated."""
 
+        debug.println(debug.LEVEL_FINEST, 'INFO: Activating script manager')
         self._defaultScript  = None
         self.setActiveScript(self.getScript(None), "activate")
+        debug.println(debug.LEVEL_FINEST, 'INFO: Script manager activated')
 
     def deactivate(self):
         """Called when this script manager is deactivated."""
 
+        debug.println(debug.LEVEL_FINEST, 'INFO: Dectivating script manager')
         self._defaultScript  = None
         self.setActiveScript(None, "deactivate")
         self.appScripts = {}
         self.toolkitScripts = {}
+        debug.println(debug.LEVEL_FINEST, 'INFO: Script manager deactivated')
 
     def getModuleName(self, app):
         """Returns the module name of the script to use for application app."""
@@ -99,14 +107,14 @@ class ScriptManager:
         # Many python apps have an accessible name which ends in '.py'.
         # Sometimes OOo has 'soffice.bin' as its name.
         name = app.name.split('.')[0]
-        altNames = self._appNames.keys()
+        altNames = list(self._appNames.keys())
 
-        names = filter(lambda n: n.lower() == name.lower(), altNames)
+        names = [n for n in altNames if n.lower() == name.lower()]
         if names:
             name = self._appNames.get(names[0])
         else:
             for nameList in (self._appModules, self._toolkitModules):
-                names = filter(lambda n: n.lower() == name.lower(), nameList)
+                names = [n for n in nameList if n.lower() == name.lower()]
                 if names:
                     name = names[0]
                     break
@@ -138,8 +146,8 @@ class ScriptManager:
         if not (app and name):
             return None
 
-        altNames = self._toolkitNames.keys()
-        names = filter(lambda n: n.lower() == name.lower(), altNames)
+        altNames = list(self._toolkitNames.keys())
+        names = [n for n in altNames if n.lower() == name.lower()]
         if names:
             newName = self._toolkitNames.get(names[0])
             debug.println(debug.LEVEL_FINEST,
@@ -185,8 +193,14 @@ class ScriptManager:
         if script:
             return script
 
-        if app and getattr(app, "toolkitName", None):
-            script = self._newNamedScript(app, app.toolkitName)
+        try:
+            toolkitName = getattr(app, "toolkitName", None)
+        except (LookupError, RuntimeError):
+            msg = "Error getting toolkitName for: %s" % app
+            debug.println(debug.LEVEL_FINE, msg)
+        else:
+            if app and toolkitName:
+                script = self._newNamedScript(app, toolkitName)
 
         if not script:
             script = self.getDefaultScript(app)
@@ -198,7 +212,7 @@ class ScriptManager:
         if not app and self._defaultScript:
             return self._defaultScript
 
-        import scripts.default as default
+        from .scripts import default
         script = default.Script(app)
         _eventManager.registerScriptListeners(script)
 
@@ -282,8 +296,8 @@ class ScriptManager:
             debug.printException(debug.LEVEL_FINEST)
             return
 
-        appList = self.appScripts.keys()
-        appList = filter(lambda a: a!= None and a not in desktop, appList)
+        appList = list(self.appScripts.keys())
+        appList = [a for a in appList if a!= None and a not in desktop]
         for app in appList:
             appScript = self.appScripts.pop(app)
             _eventManager.deregisterScriptListeners(appScript)
@@ -294,7 +308,7 @@ class ScriptManager:
             except KeyError:
                 pass
             else:
-                for toolkitScript in toolkitScripts.values():
+                for toolkitScript in list(toolkitScripts.values()):
                     _eventManager.deregisterScriptListeners(toolkitScript)
                     del toolkitScript
 
