@@ -36,10 +36,10 @@ import orca.scripts.toolkits.Gecko as Gecko
 
 from orca.orca_i18n import _
 
-from formatting import Formatting
-from speech_generator import SpeechGenerator
-from script_utilities import Utilities
-import script_settings
+from .formatting import Formatting
+from .speech_generator import SpeechGenerator
+from .script_utilities import Utilities
+from . import script_settings
 
 _settingsManager = getattr(orca, '_settingsManager')
 
@@ -266,7 +266,8 @@ class Script(Gecko.Script):
         # cell and consume the event so that the Gecko script
         # doesn't reset it.
         #
-        if obj.getRole() == pyatspi.ROLE_TABLE_CELL:
+        if obj.getRole() == pyatspi.ROLE_TABLE_CELL \
+           and parent.getRole() != pyatspi.ROLE_LIST_ITEM:
             table = parent.queryTable()
             row = table.getRowAtIndex(self.utilities.cellIndex(obj))
             for i in range(0, table.nColumns):
@@ -480,6 +481,10 @@ class Script(Gecko.Script):
         # address so that we're not too "chatty." See bug #533042.
         #
         if parent.getRole() == pyatspi.ROLE_AUTOCOMPLETE:
+            if len(event.any_data) == 1:
+                default.Script.onTextInserted(self, event)
+                return
+
             if event.type.endswith("system") and event.any_data:
                 # The autocompleted address may start with the name,
                 # or it might start with the text typed by the user
