@@ -4,7 +4,6 @@ __all__ = ['acroread',
            'Eclipse',
            'ekiga',
            'empathy',
-           'epiphany',
            'evolution',
            'gajim',
            'gcalctool',
@@ -33,5 +32,4 @@ __all__ = ['acroread',
            'rhythmbox',
            'soffice',
            'Thunderbird',
-           'xfwm4',
-           'yelp']
+           'xfwm4']
