@@ -52,12 +52,12 @@ import orca.settings as settings
 from orca.orca_i18n import _ # for gettext support
 from orca.orca_i18n import ngettext
 
-from speech_generator import SpeechGenerator
-from braille_generator import BrailleGenerator
-from formatting import Formatting
-from structural_navigation import StructuralNavigation
-from script_utilities import Utilities
-import script_settings
+from .speech_generator import SpeechGenerator
+from .braille_generator import BrailleGenerator
+from .formatting import Formatting
+from .structural_navigation import StructuralNavigation
+from .script_utilities import Utilities
+from . import script_settings
 
 _settingsManager = getattr(orca, '_settingsManager')
 
@@ -1842,7 +1842,10 @@ class Script(default.Script):
         if not event.type.startswith('object:children-changed:add'):
             return
 
-        role = event.any_data.getRole()
+        try:
+            role = event.any_data.getRole()
+        except:
+            role = None
         if role == pyatspi.ROLE_TABLE:
             if self.isSpreadSheetCell(event.any_data, True):
                 orca.setLocusOfFocus(event, event.any_data)
@@ -1896,6 +1899,15 @@ class Script(default.Script):
         - event: the Event
         """
 
+        if event.source.getRole() == pyatspi.ROLE_EXTENDED:
+            if event.source.getRoleName() == 'text frame':
+                return
+
+        parent = event.source.parent
+        if parent and parent.getRole() == pyatspi.ROLE_EXTENDED:
+            if parent.getRoleName() == 'text frame':
+                return
+
         # If this is state change "focused" event and event.source isn't a
         # focused object, then just return. See bug #517502 for more details.
         #
