@@ -314,10 +314,10 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             return result
 
         s = obj.querySelection()
-        items = [s.getSelectedChild(i) for i in xrange(s.nSelectedChildren)]
-        if not items:
+        items = [s.getSelectedChild(i) for i in range(s.nSelectedChildren)]
+        if not items and obj.childCount:
             items.append(obj[0])
-        items = map(self._generateName, items)
+        items = list(map(self._generateName, items))
         for item in items:
             result.extend(item)
 
