@@ -1,7 +1,7 @@
 # Orca
 #
 # Copyright (C) 2010-2011 The Orca Team
-# Copyright (C) 2011 Igalia, S.L.
+# Copyright (C) 2011-2012 Igalia, S.L.
 #
 # Author: Joanmarie Diggs <jdiggs@igalia.com>
 #
@@ -24,7 +24,7 @@ __id__        = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
 __copyright__ = "Copyright (C) 2010-2011 The Orca Team" \
-                "Copyright (C) 2011 Igalia, S.L."
+                "Copyright (C) 2011-2012 Igalia, S.L."
 __license__   = "LGPL"
 
 import pyatspi
@@ -39,11 +39,11 @@ import orca.orca_state as orca_state
 import orca.speech as speech
 from orca.orca_i18n import _
 
-import script_settings
-from structural_navigation import StructuralNavigation
-from braille_generator import BrailleGenerator
-from speech_generator import SpeechGenerator
-from script_utilities import Utilities
+from . import script_settings
+from .structural_navigation import StructuralNavigation
+from .braille_generator import BrailleGenerator
+from .speech_generator import SpeechGenerator
+from .script_utilities import Utilities
 
 _settingsManager = getattr(orca, '_settingsManager')
 
@@ -107,19 +107,10 @@ class Script(default.Script):
                 #
                 _("Speaks entire document."))
 
-    def getKeyBindings(self):
-        """Defines the key bindings for this script. Setup the default
-        key bindings, then add one in for reading the input line.
+    def getToolkitKeyBindings(self):
+        """Returns the toolkit-specific keybindings for this script."""
 
-        Returns an instance of keybindings.KeyBindings.
-        """
-
-        keyBindings = default.Script.getKeyBindings(self)
-        bindings = self.structuralNavigation.keyBindings
-        for keyBinding in bindings.keyBindings:
-            keyBindings.add(keyBinding)
-
-        return keyBindings
+        return self.structuralNavigation.keyBindings
 
     def getAppPreferencesGUI(self):
         """Return a GtkGrid containing the application unique configuration
@@ -411,7 +402,7 @@ class Script(default.Script):
                 voice = self.voices[settings.DEFAULT_VOICE]
 
             phrase = self.utilities.adjustForRepeats(phrase)
-            links = filter(lambda x: x.getRole() == pyatspi.ROLE_LINK, obj)
+            links = [x for x in obj if x.getRole() == pyatspi.ROLE_LINK]
             if links:
                 phrase = self.utilities.adjustForLinks(obj, phrase, startOffset)
             speech.speak(phrase, voice)
@@ -456,8 +447,12 @@ class Script(default.Script):
         if not self.utilities.isWebKitGtk(orca_state.locusOfFocus):
             return False
 
-        if orca_state.locusOfFocus.getRole() in doNotHandleRoles:
+        role = orca_state.locusOfFocus.getRole()
+        if role in doNotHandleRoles:
             states = orca_state.locusOfFocus.getState()
+            if role == pyatspi.ROLE_LIST_ITEM:
+                return not states.contains(pyatspi.STATE_SELECTABLE)
+
             if states.contains(pyatspi.STATE_FOCUSED):
                 return False
 
@@ -487,7 +482,7 @@ class Script(default.Script):
 
         index = -1
         text = child.queryText()
-        for i in xrange(text.characterCount):
+        for i in range(text.characterCount):
             if text.setCaretOffset(i):
                 index = i
                 break
@@ -540,7 +535,7 @@ class Script(default.Script):
         allTextObjs = utils.findAllDescendants(
             document, lambda x: 'Text' in utils.listInterfaces(x))
         allTextObjs = allTextObjs[allTextObjs.index(obj):len(allTextObjs)]
-        textObjs = filter(lambda x: x.parent not in allTextObjs, allTextObjs)
+        textObjs = [x for x in allTextObjs if x.parent not in allTextObjs]
         if not textObjs:
             return
 
@@ -588,7 +583,7 @@ class Script(default.Script):
         else:
             linkCount = hypertext.getNLinks()
             links = [hypertext.getLink(x) for x in range(linkCount)]
-            if filter(lambda l: l.startIndex <= offset <= l.endIndex, links):
+            if [l for l in links if l.startIndex <= offset <= l.endIndex]:
                 return
 
         text.setCaretOffset(offset)
