@@ -1,7 +1,7 @@
 # Orca
 #
 # Copyright (C) 2010 Joanmarie Diggs
-# Copyright (C) 2011 Igalia, S.L.
+# Copyright (C) 2011-2012 Igalia, S.L.
 #
 # Author: Joanmarie Diggs <jdiggs@igalia.com>
 #
@@ -24,7 +24,7 @@ __id__ = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2010 Joanmarie Diggs." \
-                "Copyright (c) 2011 Igalia, S.L."
+                "Copyright (c) 2011-2012 Igalia, S.L."
 __license__   = "LGPL"
 
 import pyatspi
@@ -102,6 +102,10 @@ class Utilities(script_utilities.Utilities):
         """
 
         text = script_utilities.Utilities.displayedText(self, obj)
+        try:
+            text = text.decode('UTF-8')
+        except:
+            pass
         if text and text != self.EMBEDDED_OBJECT_CHARACTER:
             return text
 
@@ -148,16 +152,19 @@ class Utilities(script_utilities.Utilities):
 
         pattern = re.compile(self.EMBEDDED_OBJECT_CHARACTER)
         offsets = [m.start(0) for m in re.finditer(pattern, string)]
-        offsets = filter(lambda x: start <= x < end, offsets)
+        offsets = [x for x in offsets if start <= x < end]
 
         objects = []
-        objs = [obj[htext.getLinkIndex(offset)] for offset in offsets]
+        try:
+            objs = [obj[htext.getLinkIndex(offset)] for offset in offsets]
+        except:
+            objs = []
         ranges = [self.getHyperlinkRange(x) for x in objs]
         for i, (first, last) in enumerate(ranges):
             objects.append((obj, start, first, string[start:first]))
             objects.append((objs[i], first, last, ''))
             start = last
         objects.append((obj, start, end, string[start:end]))
-        objects = filter(lambda x: x[1] < x[2], objects)
+        objects = [x for x in objects if x[1] < x[2]]
 
         return objects
