@@ -27,34 +27,11 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import os
-
-tty = 7
-
-try:
-    # This can fail due to gtk not being available.  We want to
-    # be able to recover from that if possible.  The main driver
-    # for this is to allow "orca --text-setup" to work even if
-    # the desktop is not running.
-    #
-    from gi.repository import Gdk
-    _display = Gdk.Display.get_default()
-    _screen = _display.get_default_screen()
-    _root_window = _screen.get_root_window()
-
-    # We want to know what the tty is so we can send it to BrlAPI
-    # if possible.
-    #
-    (atom, format, data) = _root_window.property_get("XFree86_VT")
-    tty = data[0]
-except:
-    pass
-
 import pyatspi
 
-from acss import ACSS
-from orca_i18n import _           # for gettext support
-from orca_i18n import C_          # to provide qualified translatable strings
+from .acss import ACSS
+from .orca_i18n import _
+from .orca_i18n import C_
 
 # These are the settings that Orca supports the user customizing.
 #
@@ -134,14 +111,12 @@ userCustomizableSettings = [
     "presentTimeFormat",
     "activeProfile",
     "startingProfile",
-    "firstStart"
 ]
 
 excludeKeys = ["pronunciations",
                "keybindings",
                "startingProfile",
-               "activeProfile",
-               "firstStart"]
+               "activeProfile"]
 
 # The name of the module that hold the user interface for the main window
 # for Orca. This module is expected to have two methods, showMainUI and
@@ -178,10 +153,6 @@ startingProfile = ['Default', 'default']
 activeProfile = ['Default', 'default']
 profile = ['Default', 'default']
 
-# First start?
-#
-firstStart = True
-
 # A list of keys that can serve as the Orca modifier key.  The list is
 # so we can provide better cross platform support (e.g., Sun keyboard
 # vs. PC-104 keyboard layouts).  When any of these keys is pressed,
@@ -282,27 +253,6 @@ speechRateDelta         = 5
 #
 speechPitchDelta        = 0.5
 
-# The port to listen on if orca is to act as an HTTP server
-# (mainly as a speech server for self-voicing applications).
-#
-httpServerPort          = 0
-
-# The number of attempts to retry setting up an HTTP server
-# connection (each time incrementing the port number by 1).
-#
-maxHttpServerRetries    = 20
-
-# Whether or not to use DBUS.
-#
-if os.getenv("DBUS_SESSION_BUS_ADDRESS"):
-    useDBus = True
-else:
-    useDBus = False
-
-# Whether or not recording is enabled via the HTTP server.
-#
-enableRemoteLogging     = False
-
 # If True, enable speech.
 #
 enableSpeech            = True
@@ -338,10 +288,10 @@ voicesKeys = {
 
 
 voices = {
-    DEFAULT_VOICE   : ACSS({}),
-    UPPERCASE_VOICE : ACSS({ACSS.AVERAGE_PITCH : 5.6}),
-    HYPERLINK_VOICE : ACSS({}),
-    SYSTEM_VOICE    : ACSS({}),
+    DEFAULT_VOICE: ACSS({}),
+    UPPERCASE_VOICE: ACSS({ACSS.AVERAGE_PITCH : 5.6}),
+    HYPERLINK_VOICE: ACSS({}),
+    SYSTEM_VOICE: ACSS({}),
 }
 
 # If True, enable speaking of speech indentation and justification.
@@ -446,6 +396,10 @@ enablePositionSpeaking = False
 #
 showMainWindow          = True
 
+# If True, show the splash window.
+#
+showSplashWindow          = True
+
 # If True, quit Orca without confirmation when the user presses
 # <Orca-modifier>-q.
 #
@@ -644,16 +598,6 @@ cacheDescriptions       = True
 #
 cacheAccessibles        = True
 
-# Assists with learn mode (what you enter when you press Insert+F1
-# and exit when you press escape.
-#
-learnModeEnabled        = False
-
-# Assists with list shortcuts mode (what you enter when you press 
-# Insert + H (double click) and exit when you press escape.
-#
-listShortcutsModeEnabled = False
-
 # If non-zero, we use time.sleep() in various places to attempt to
 # free up the global interpreter lock.  Take a look at the following
 # URLs for more information:
@@ -737,7 +681,7 @@ chatRoomHistories = False
 # Allow for the customization of key bindings.
 #
 def overrideKeyBindings(script, keyBindings):
-    import orca
+    import orca # Deal with this during final Python 3 conversion
     _settingsManager = getattr(orca, '_settingsManager')
 
     return _settingsManager.overrideKeyBindings(script, keyBindings)
@@ -1074,3 +1018,6 @@ DATE_FORMAT_WITH_LONG_NAMES = DATE_FORMAT_FULL_DMY
 DATE_FORMAT_WITH_SHORT_NAMES = DATE_FORMAT_ABBREVIATED_DMY
 
 presentDateFormat = DATE_FORMAT_LOCALE
+
+# Default tty to pass along to brlapi.
+tty = 7
