@@ -28,26 +28,26 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2010 Consorcio Fernando de los Rios."
 __license__   = "LGPL"
 
-import dbus
 import os
 import imp
-from dbus.mainloop.glib import DBusGMainLoop
-from json import load
-from xdg.BaseDirectory import xdg_data_home
+from gi.repository import Gio, GLib
 
-import debug
-from keybindings import KeyBinding
-import settings
-import pronunciation_dict
+from . import debug
+from .keybindings import KeyBinding
+from . import settings
+from . import pronunciation_dict
 
 try:
-    _dbusLoop = DBusGMainLoop()
-    _bus = dbus.SessionBus(mainloop=_dbusLoop)
-    _proxy = _bus.get_object("org.a11y.Bus", "/org/a11y/bus")
-    _desktopProps = \
-        dbus.Interface(_proxy, dbus_interface='org.freedesktop.DBus.Properties')
+    _proxy = Gio.DBusProxy.new_for_bus_sync(
+        Gio.BusType.SESSION,
+        Gio.DBusProxyFlags.NONE,
+        None,
+        'org.a11y.Bus',
+        '/org/a11y/bus',
+        'org.freedesktop.DBus.Properties',
+        None)
 except:
-    _desktopProps = None
+    _proxy = None
 
 class SettingsManager(object):
     """Settings backend manager. This class manages orca user's settings
@@ -59,7 +59,7 @@ class SettingsManager(object):
             cls.__instance = object.__new__(cls, *args, **kwargs)
         return cls.__instance
 
-    def __init__(self, backend='json', prefsDir=None):
+    def __init__(self, backend='json'):
         """Initialize a SettingsManager Object.
         If backend isn't defined then uses default backend, in this
         case json-backend.
@@ -73,7 +73,7 @@ class SettingsManager(object):
         self._backend = None
         self.profile = None
         self.backendName = backend
-        self._prefsDir = prefsDir or os.path.join(xdg_data_home, "orca")
+        self._prefsDir = None
 
         # Dictionaries for store the default values
         # The keys and values are defined at orca.settings
@@ -100,11 +100,24 @@ class SettingsManager(object):
         self.keybindings = {}
 
         if not self._loadBackend():
-            raise Exception('SettingsManager::_loadBackend fails.')
+            raise Exception('SettingsManager._loadBackend failed.')
 
         self.customizedSettings = {}
         self._customizationCompleted = False
 
+        # For handling the currently-"classic" application settings
+        self.settingsPackages = ["app-settings"]
+        self._knownAppSettings = {}
+
+        debug.println(debug.LEVEL_FINEST, 'INFO: Settings manager initialized')
+
+    def activate(self, prefsDir=None, customSettings={}):
+        debug.println(debug.LEVEL_FINEST, 'INFO: Activating settings manager')
+
+        self.customizedSettings.update(customSettings)
+        self._prefsDir = prefsDir \
+            or os.path.join(GLib.get_user_data_dir(), "orca")
+
         # Load the backend and the default values
         self._backend = self.backendModule.Backend(self._prefsDir)
         self._setDefaultGeneral()
@@ -123,17 +136,13 @@ class SettingsManager(object):
         #
         self._createDefaults()
 
+        debug.println(debug.LEVEL_FINEST, 'INFO: Settings manager activated')
+
         # Set the active profile and load its stored settings
         if self.profile is None:
             self.profile = self.general.get('startingProfile')[1]
         self.setProfile(self.profile)
 
-        # For handling the currently-"classic" application settings
-        self.settingsPackages = ["app-settings"]
-        self._knownAppSettings = {}
-
-        debug.println(debug.LEVEL_FINEST, 'INFO: Settings manager initialized')
-
     def _loadBackend(self):
         """Load specific backend for manage user settings"""
 
@@ -165,7 +174,7 @@ class SettingsManager(object):
         _createDir(orcaScriptDir)
         initFile = os.path.join(orcaScriptDir, "__init__.py")
         if not os.path.exists(initFile):
-            os.close(os.open(initFile, os.O_CREAT, 0700))
+            os.close(os.open(initFile, os.O_CREAT, 0o700))
 
         # Set up $XDG_DATA_HOME/orca/app-settings as a Python package.
         #
@@ -173,17 +182,17 @@ class SettingsManager(object):
         _createDir(orcaSettingsDir)
         initFile = os.path.join(orcaSettingsDir, "__init__.py")
         if not os.path.exists(initFile):
-            os.close(os.open(initFile, os.O_CREAT, 0700))
+            os.close(os.open(initFile, os.O_CREAT, 0o700))
 
         # Set up $XDG_DATA_HOME/orca/orca-customizations.py empty file and
         # define orcaDir as a Python package.
         initFile = os.path.join(orcaDir, "__init__.py")
         if not os.path.exists(initFile):
-            os.close(os.open(initFile, os.O_CREAT, 0700))
+            os.close(os.open(initFile, os.O_CREAT, 0o700))
 
         userCustomFile = os.path.join(orcaDir, "orca-customizations.py")
         if not os.path.exists(userCustomFile):
-            os.close(os.open(userCustomFile, os.O_CREAT, 0700))
+            os.close(os.open(userCustomFile, os.O_CREAT, 0o700))
 
         if self.isFirstStart():
             self._backend.saveDefaultSettings(self.defaultGeneral,
@@ -216,12 +225,12 @@ class SettingsManager(object):
             return self.customizedSettings
 
         originalSettings = {}
-        for key, value in settings.__dict__.items():
+        for key, value in list(settings.__dict__.items()):
             originalSettings[key] = value
 
         self._customizationCompleted = self._loadUserCustomizations()
 
-        for key, value in originalSettings.items():
+        for key, value in list(originalSettings.items()):
             customValue = settings.__dict__.get(key)
             if value != customValue:
                 self.customizedSettings[key] = customValue
@@ -315,27 +324,27 @@ class SettingsManager(object):
         return not alreadyEnabled
 
     def isAccessibilityEnabled(self):
-        if not _desktopProps:
+        if not _proxy:
             return False
 
-        return bool(_desktopProps.Get('org.a11y.Status', 'IsEnabled'))
+        return _proxy.Get('(ss)', 'org.a11y.Status', 'IsEnabled')
 
     def setAccessibility(self, enable):
-        if not _desktopProps:
+        if not _proxy:
             return False
 
-        _desktopProps.Set('org.a11y.Status', 'IsEnabled', enable)
-        return True
+        vEnable = GLib.Variant('b', enable)
+        _proxy.Set('(ssv)', 'org.a11y.Status', 'IsEnabled', vEnable)            
 
     def isScreenReaderServiceEnabled(self):
         """Returns True if the screen reader service is enabled. Note that
         this does not necessarily mean that Orca (or any other screen reader)
         is running at the moment."""
 
-        if not _desktopProps:
+        if not _proxy:
             return False
 
-        return bool(_desktopProps.Get('org.a11y.Status', 'ScreenReaderEnabled'))
+        return _proxy.Get('(ss)', 'org.a11y.Status', 'ScreenReaderEnabled')
 
     def setStartingProfile(self, profile=None):
         if profile is None:
@@ -358,10 +367,10 @@ class SettingsManager(object):
         return (general, pronunciations, keybindings)
 
     def _setSettingsRuntime(self, settingsDict):
-        for key, value in settingsDict.items():
+        for key, value in list(settingsDict.items()):
             setattr(settings, str(key), value)
         self._getCustomizedSettings()
-        for key, value in self.customizedSettings.items():
+        for key, value in list(self.customizedSettings.items()):
             setattr(settings, str(key), value)
         self._setPronunciationsRuntime()
 
@@ -397,7 +406,7 @@ class SettingsManager(object):
         as the profile's."""
         self.profileGeneral = {}
 
-        for key, value in general.items():
+        for key, value in list(general.items()):
             if isinstance(value, unicode):
                 value = value.encode('UTF-8')
             if key in settings.excludeKeys:
@@ -457,7 +466,7 @@ class SettingsManager(object):
 
     def overrideKeyBindings(self, script, scriptKeyBindings):
         keybindingsSettings = self.getKeybindings(self.profile)
-        for handlerString, bindingTuples in keybindingsSettings.items():
+        for handlerString, bindingTuples in list(keybindingsSettings.items()):
             handler = script.inputEventHandlers.get(handlerString)
             if not handler:
                 continue
@@ -486,26 +495,6 @@ class SettingsManager(object):
 
         return self._backend.availableProfiles()
 
-
-    def importProfile(self, fileName):
-        """Import profile from a given filename"""
-
-        prefs = {}
-        with open(fileName) as settingsFile:
-            prefs = load(settingsFile)
-
-        general = {}
-
-        for key, value in prefs.items():
-            if key not in settings.excludeKeys:
-                general[key] = value
-
-        pronunciations = prefs.get('pronunciations', {})
-        keybindings = prefs.get('keybindings', {})
-
-        self.saveSettings(general, pronunciations, keybindings)
-        return True
-
     def loadAppSettings(self, script):
         """Load the users application specific settings for an app.
         Note that currently the settings manager does not manage
@@ -519,7 +508,7 @@ class SettingsManager(object):
         self._loadProfileSettings()
         script.voices = self.getSetting('voices')
 
-        import orca
+        import orca # Deal with this during final Python 3 conversion
         _scriptManager = getattr(orca, '_scriptManager')
 
         app = script.app
@@ -553,7 +542,7 @@ class SettingsManager(object):
         reload(self._knownAppSettings[name])
 
         appVoices = self.getSetting('voices')
-        for voiceType, voiceDef in appVoices.items():
+        for voiceType, voiceDef in list(appVoices.items()):
             script.voices[voiceType].update(voiceDef)
 
         keybindings = getattr(module, 'overrideAppKeyBindings', None)
@@ -569,7 +558,7 @@ class SettingsManager(object):
 
 def getVoiceKey(voice):
     voicesKeys = getattr(settings, 'voicesKeys')
-    for key in voicesKeys.keys():
+    for key in list(voicesKeys.keys()):
         if voicesKeys[key] == voice:
             return key
     return ""
@@ -583,7 +572,7 @@ def getValueForKey(prefsDict, key):
 
     value = None
     if key in prefsDict:
-        if type(prefsDict[key]) is str:
+        if isinstance(prefsDict[key], str):
             if key in need2repr:
                 value = "\'%s\'" % prefsDict[key]
             elif key  == 'voices':
