@@ -29,15 +29,17 @@ import pyatspi
 import urlparse, urllib2
 from gi.repository import Atspi, Atk
 
-import generator
-import orca
-import settings
-import sound
-import text_attribute_names
+import orca # Deal with this during final Python 3 conversion
 
-from orca_i18n import _         # for gettext support
-from orca_i18n import ngettext  # for ngettext support
-from orca_i18n import C_        # to provide qualified translatable strings
+from . import debug
+from . import generator
+from . import settings
+from . import sound
+from . import text_attribute_names
+
+from .orca_i18n import _
+from .orca_i18n import ngettext
+from .orca_i18n import C_
 
 class Pause:
     """A dummy class to indicate we want to insert a pause into an
@@ -72,12 +74,12 @@ STATE          = "state" # Candidate for sound
 VALUE          = "value" # Candidate for sound
 
 voiceType = {
-    DEFAULT     : settings.DEFAULT_VOICE,
-    UPPERCASE   : settings.UPPERCASE_VOICE,
-    HYPERLINK   : settings.HYPERLINK_VOICE,
-    SYSTEM      : settings.SYSTEM_VOICE,
-    STATE       : settings.SYSTEM_VOICE, # Users may prefer DEFAULT_VOICE here
-    VALUE       : settings.SYSTEM_VOICE, # Users may prefer DEFAULT_VOICE here
+    DEFAULT: settings.DEFAULT_VOICE,
+    UPPERCASE: settings.UPPERCASE_VOICE,
+    HYPERLINK: settings.HYPERLINK_VOICE,
+    SYSTEM: settings.SYSTEM_VOICE,
+    STATE: settings.SYSTEM_VOICE, # Users may prefer DEFAULT_VOICE here
+    VALUE: settings.SYSTEM_VOICE, # Users may prefer DEFAULT_VOICE here
 }
 
 _settingsManager = getattr(orca, '_settingsManager')
@@ -140,7 +142,12 @@ class SpeechGenerator(generator.Generator):
         needed a _generateDescription for whereAmI. :-) See below.
         """
 
-        role = args.get('role', obj.getRole())
+        try:
+            role = args.get('role', obj.getRole())
+        except (LookupError, RuntimeError):
+            debug.println(debug.LEVEL_FINE, "Error getting role for: %s" % obj)
+            role = None
+
         if role == pyatspi.ROLE_LAYERED_PANE:
             if _settingsManager.getSetting('onlySpeakDisplayedText'):
                 return []
@@ -281,7 +288,10 @@ class SpeechGenerator(generator.Generator):
             try:
                 return obj.getLocalizedRoleName()
             except:
-                pass
+                return ''
+
+        if not role:
+            return ''
 
         nonlocalized = Atspi.role_get_name(role)
         atkRole = Atk.role_for_name(nonlocalized)
@@ -1518,8 +1528,11 @@ class SpeechGenerator(generator.Generator):
         # dialog window, then speak '<m> unfocused dialogs'
         # to let the user know.
         #
-        alertAndDialogCount = \
-            self._script.utilities.unfocusedAlertAndDialogCount(obj)
+        try:
+            alertAndDialogCount = \
+                self._script.utilities.unfocusedAlertAndDialogCount(obj)
+        except:
+            alertAndDialogCount = 0
         if alertAndDialogCount > 0:
             # Translators: this tells the user how many unfocused
             # alert and dialog windows that this application has.
@@ -1562,8 +1575,12 @@ class SpeechGenerator(generator.Generator):
                             or (requireText \
                                 and 'Text' in pyatspi.listInterfaces(parent))):
                         text = self._script.utilities.displayedText(parent)
-                    if not text and parent.getRole() \
-                           in [pyatspi.ROLE_MENU, pyatspi.ROLE_PAGE_TAB]:
+                    try:
+                        pRole = parent.getRole()
+                    except:
+                        pRole = None
+                    if not text \
+                       and pRole in [pyatspi.ROLE_MENU, pyatspi.ROLE_PAGE_TAB]:
                         text = parent.name
                     if text and len(text.strip()):
                         roleInfo = self._generateRoleName(parent)
@@ -1571,12 +1588,12 @@ class SpeechGenerator(generator.Generator):
                             roleInfo.reverse()
                         # Push announcement of cell to the end
                         #
-                        if parent.getRole() not in [pyatspi.ROLE_TABLE_CELL,
-                                                    pyatspi.ROLE_FILLER]:
+                        if pRole not in \
+                               [pyatspi.ROLE_TABLE_CELL, pyatspi.ROLE_FILLER]:
                             result.extend(roleInfo)
                         result.extend(acss)
                         result.append(text)
-                        if parent.getRole() == pyatspi.ROLE_TABLE_CELL:
+                        if pRole == pyatspi.ROLE_TABLE_CELL:
                             result.extend(roleInfo)
                 parent = parent.parent
         result.reverse()
@@ -1640,7 +1657,10 @@ class SpeechGenerator(generator.Generator):
         position = -1
         total = -1
 
-        relations = obj.getRelationSet()
+        try:
+            relations = obj.getRelationSet()
+        except:
+            relations = []
         for relation in relations:
             if relation.getRelationType() == pyatspi.RELATION_MEMBER_OF:
                 total = 0
