@@ -41,14 +41,14 @@ __license__   = "LGPL"
 from gi.repository import GObject
 import re
 
-import chnames
-import debug
-import speechserver
-import settings
-import orca_state
-import punctuation_settings
-from acss import ACSS
-from orca_i18n import _
+from . import chnames
+from . import debug
+from . import speechserver
+from . import settings
+from . import orca_state
+from . import punctuation_settings
+from .acss import ACSS
+from .orca_i18n import _
 
 try:
     import speechd
@@ -129,7 +129,7 @@ class SpeechServer(speechserver.SpeechServer):
     getSpeechServer = staticmethod(getSpeechServer)
 
     def shutdownActiveServers():
-        for server in SpeechServer._active_servers.values():
+        for server in list(SpeechServer._active_servers.values()):
             server.shutdown()
     shutdownActiveServers = staticmethod(shutdownActiveServers)
 
@@ -353,7 +353,7 @@ class SpeechServer(speechserver.SpeechServer):
 
         """
         try:
-            context, acss = iterator.next()
+            context, acss = next(iterator)
         except StopIteration:
             pass
         else:
@@ -373,7 +373,7 @@ class SpeechServer(speechserver.SpeechServer):
                 if t == speechserver.SayAllContext.COMPLETED:
                     GObject.idle_add(self._say_all, iterator, orca_callback)
             self._speak(context.utterance, acss, callback=callback,
-                        event_types=self._CALLBACK_TYPE_MAP.keys())
+                        event_types=list(self._CALLBACK_TYPE_MAP.keys()))
         return False # to indicate, that we don't want to be called again.
 
     def _cancel(self):
@@ -382,7 +382,10 @@ class SpeechServer(speechserver.SpeechServer):
     def _change_default_speech_rate(self, decrease=False):
         acss = settings.voices[settings.DEFAULT_VOICE]
         delta = settings.speechRateDelta * (decrease and -1 or +1)
-        rate = acss[ACSS.RATE]
+        try:
+            rate = acss[ACSS.RATE]
+        except KeyError:
+            rate = 50
         acss[ACSS.RATE] = max(0, min(99, rate + delta))
         debug.println(debug.LEVEL_CONFIGURATION,
                       "Speech rate is now %d" % rate)
@@ -392,7 +395,10 @@ class SpeechServer(speechserver.SpeechServer):
     def _change_default_speech_pitch(self, decrease=False):
         acss = settings.voices[settings.DEFAULT_VOICE]
         delta = settings.speechPitchDelta * (decrease and -1 or +1)
-        pitch = acss[ACSS.AVERAGE_PITCH]
+        try:
+            pitch = acss[ACSS.AVERAGE_PITCH]
+        except KeyError:
+            pitch = 5
         acss[ACSS.AVERAGE_PITCH] = max(0, min(9, pitch + delta))
         debug.println(debug.LEVEL_CONFIGURATION,
                       "Speech pitch is now %d" % pitch)
